#
# spec file for package cinnamon-control-center
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libcinnamon-control-center
%define sover   1
Name:           cinnamon-control-center
Version:        4.6.2
Release:        lp154.1.9
Summary:        Utilities to configure the Cinnamon desktop
License:        GPL-2.0-only AND GPL-3.0-or-later AND MIT
Group:          System/GUI/Other
URL:            https://github.com/linuxmint/cinnamon-control-center
Source:         https://github.com/linuxmint/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE %%{name}-ignore-polkit-rules.patch - marguerite@opensuse.org fix boo#1125427
Patch:          %{name}-ignore-polkit-rules.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  cups-devel
BuildRequires:  desktop-data
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(cinnamon-desktop)
BuildRequires:  pkgconfig(cinnamon-settings-daemon)
BuildRequires:  pkgconfig(colord) >= 0.1.14
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.23.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.31.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.31.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(goa-1.0) >= 3.18.0
BuildRequires:  pkgconfig(goa-backend-1.0) >= 3.18.0
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libcanberra-gtk3) >= 0.13
BuildRequires:  pkgconfig(libcinnamon-menu-3.0)
BuildRequires:  pkgconfig(libgnomekbd)
BuildRequires:  pkgconfig(libgnomekbdui)
BuildRequires:  pkgconfig(libnotify) >= 0.7.3
BuildRequires:  pkgconfig(libpulse) >= 1.1
BuildRequires:  pkgconfig(libpulse-mainloop-glib) >= 1.1
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libwacom)
BuildRequires:  pkgconfig(libxklavier) >= 5.1
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.103
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi) >= 1.2
Requires:       %{name}-common = %{version}
Requires:       accountsservice
Requires:       adwaita-icon-theme
Requires:       cinnamon-settings-daemon
Requires:       desktop-data
Requires:       gnome-online-accounts
Requires:       polkit-gnome
Recommends:     %{name}-lang
Recommends:     iso-codes
Recommends:     mousetweaks
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(libnm) >= 1.2.0
BuildRequires:  pkgconfig(libnma) >= 1.2.0
BuildRequires:  pkgconfig(mm-glib) >= 0.7
%endif

%description
This package contains configuration applets for the Cinnamon
desktop, allowing to set accessibility configuration, desktop
fonts, keyboard and mouse properties, sound setup, desktop theme
and background, user interface properties, screen resolution, and
other Cinnamon parameters.

%package common
Summary:        Common files for the Cinnamon configuration utilities
Group:          System/GUI/Other
Recommends:     %{name}-lang
BuildArch:      noarch

%description common
This package contains common files (icons, pixmaps, locales files)
needed by the configuration applets in the cinnamon-control-center
package.

%package -n %{soname}%{sover}
Summary:        Shared libraries for the Cinnamon configuration utilities
Group:          System/Libraries

%description -n %{soname}%{sover}
This package provides shared libraries used by Cinnamon control
centre applets.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{sover} = %{version}

%description devel
This package contains all necessary include files and libraries
needed to develop applications that require these.

%prep
%setup -q
%patch -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --disable-static         \
  --disable-update-mimedb  \
%if 0%{?suse_version} < 1500
  --disable-networkmanager \
  --disable-modemmanager   \
%endif
  --enable-systemd
make %{?_smp_mflags} V=1

%install
%make_install

ls %{buildroot}%{_datadir}/applications/cinnamon-* | while read desktop; do
    %suse_update_desktop_file $desktop
done

find %{buildroot} -type f -name "*.la" -delete -print

%find_lang %{name}-timezones
%fdupes %{buildroot}%{_datadir}/

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun

%post common
%icon_theme_cache_post

%postun common
%icon_theme_cache_postun
%endif

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files
%license COPYING
%doc README debian/changelog
%{_bindir}/cinnamon-*
%{_datadir}/applications/cinnamon-*.desktop

%files common -f %{name}-timezones.lang
%config %{_sysconfdir}/xdg/menus/cinnamoncc.menu
%{_datadir}/%{name}/
%dir %{_datadir}/desktop-directories/
%{_datadir}/desktop-directories/cinnamoncc.directory
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/polkit-1/actions/org.cinnamon.controlcenter.datetime.policy

%files -n %{soname}%{sover}
%{_libdir}/%{name}-%{sover}/
%{_libdir}/%{soname}.so.%{sover}*

%files devel
%{_includedir}/%{name}-%{sover}/
%{_libdir}/pkgconfig/%{soname}.pc
%{_libdir}/%{soname}.so

%changelog
* Mon Sep 14 2020 andy great <andythe_great@pm.me>
- Update to version 4.6.2.
  * cc-display-panel.c: Use scaled geometry when checking overlap
    and alignment while dragging.
  * cc-display-panel.c: Realign after a rotation change, re-scale
    and center the view after a grab ends.
  * cc-display-panel.c: Improve display representation while
    dragging.
  * cc-display-panel.c: Use a scrolled window in the error popup,
    and add a reset button to the panel.
  * cc-display-panel.c: Update the view after toggling the
    fractional scale switch.
  * cc-display-panel.c: Never scale the output width and height.
  * cc-display-panel.c: Fill in all geometry for non-active
    monitors, not just the size, to ensure uninitialized values
    don't get returned to callers.
  * cc-display-panel.c: Don't allow monitors to be dragged apart.
  * remove outdated build dependency on dbus-glib
- Remove Requires:libcinnamon-desktop-data because
  cinnamon-settings-daemon already pull in the dependency.
* Mon Mar 16 2020 Marguerite Su <i@marguerite.su>
- update version 4.4.0
  * display: Clean up a couple labels in ui file
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Wed Aug  7 2019 Marguerite Su <i@marguerite.su>
- Add patch cinnamon-control-center-ignore-polkit-rules.patch
  * granting members of wheel group special privileges is not allowed
    do a normal request (boo#1125427)
* Sun Jul 28 2019 Marguerite Su <i@marguerite.su>
- Update to version 4.2.2:
  * GOA Remove desktop file
* Sun Jul 21 2019 Marguerite Su <i@marguerite.su>
- Update to version 4.2.1:
  * Fix network settings, fixes e.g. eduroam
* Mon Jul  1 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 4.2.0:
  * network.ui: Provide a height request for the toplevel widget.
* Mon Jul  1 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 4.0.1:
  * Wacom: Add a switch to set automatic rotation
  * Wacom: Don't disable auto-rotation when disabling monitor mapping
  * l10n: Update POT
* Wed Mar 13 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 4.0.0:
  * Wacom: Add a switch to set automatic rotation
  * Wacom: Don't disable auto-rotation when disabling monitor mapping
  * l10n: Update POT
* Wed Sep 12 2018 sor.alexei@meowr.ru
- Update to version 3.8.2:
  * wacom: Update to support 3-button and 3D styli.
* Fri Jul 20 2018 sor.alexei@meowr.ru
- Update to version 3.8.1:
  * cc-color-panel.c: Use cinnamon-desktop packagekit methods to
    install gnome-color-manager.
  * Remove a stray "]" in configure.ac.
- Remove the unneeded libnm-util build dependency.
- Restore the systemd-timedated1 polkit policy as bsc#1090371 has
  been resolved.
* Mon Jun  4 2018 bjorn.lie@gmail.com
- Drop pkgconfig(libsocialweb-client) BuildRequires and
  - -with-libsocialweb configure call, no longer needed nor is it
  supported.
* Sat May 26 2018 sor.alexei@meowr.ru
- Remove the systemd-timedated1 polkit policy which automatically
  forces a fallback to cinnamon-settings-daemon due to bsc#1090371
  being unresolved (boo#1091701).
* Thu Apr 19 2018 sor.alexei@meowr.ru
- Update to version 3.8.0:
  * datetime widget: Use systemd-timedated1 to set time and NTP if
    available, otherwise fall back to csd's datetime service.
  * datetime: Fix Makefile build ordering.
  * Fix non modemmanager build.
  * Colour: Remove help link.
  * region panel: Add an option to show uncommon/exotic layouts in
    the selection list.
  * network: Update with backported bugfixes.
  * Stop requiring NetworkManager.pc.
* Tue Nov 21 2017 sor.alexei@meowr.ru
- Update to version 3.6.5 (changes since 3.6.3):
  * network: Avoid crashing if the NMDevice doesn't have a
    hw-address.
  * all: Simplify and fix i18n.
  * online-accounts: Fix Gtk-warning.
  * network: Enable loading of newer VPN plugins
    (gh#linuxmint/cinnamon-control-center#183).
  * all: Remove obsolete files and setup gitignore.
* Sat Nov 18 2017 sor.alexei@meowr.ru
- Update to version 3.6.3:
  * online-accounts: Tweak the layout just a bit.
* Sun Nov 12 2017 sor.alexei@meowr.ru
- Update to version 3.6.2:
  * Fix GOA desktop file missing proper l10n.
  * Generate desktop files.
* Sat Oct 28 2017 sor.alexei@meowr.ru
- Update to version 3.6.1 (changes since 3.4.0):
  * Make AX_ macros optional.
  * Display: Fix monitor labels not showing properly.
  * Display: Remove obsolete code.
  * Display: Clean up code and the label window.
  * Port to libnm >= 1.2, obsoleting legacy nm-glib.
  * Remove leftover variables in configure.ac.
  * Wacom: Point Bluetooth settings to Blueberry.
  * Wacom: Remove the border around the notebook widget.
  * Remove obsolete datetime desktop file.
  * Add support for online-accounts.
  * Remove libgd.
  * cc-online-accounts-panel.c: Fix assertion when setting the
    transient parent for the account dialogue.  _constructed() is
    too soon to have been added to our main settings window, so
    just set it when the dialog is actually about to be used.
  * Generate additional files.
  * Update translations.
- Remove cinnamon-control-center-ax-optional.patch: merged
  upstream.
- Move timezone locales to the cinnamon-control-center-common
  package for cinnamon-control-center-lang is being created by the
  cinnamon-translations source package.
* Thu May  4 2017 sor.alexei@meowr.ru
- Update to version 3.4.0:
  * Make colord, networkmanager/modemmanager optional.
  * wacom: Do not bail out if the tablet doesn't have an eraser.
  * wacom: Add an icon for stylii without an eraser.
  * wacom: Allow button mapping if the stylus has one button too.
  * wacom: Add margins to the UI.
  * Fix Network module.
  * display: Fix csd-xrandr D-Bus name.
  * l10n: Generate additional files.
  * Remove aclocal from autogen.sh.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 3.2.1:
  * Fix building.
  * build: Make AX_ macros optional.
  * l10n: Generate additional files.
- Rebase and rename cinnamon-control-center-3.2.0-fix-build.patch to
  cinnamon-control-center-ax-optional.patch.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Migrate away from gnome-common deprecated vars and macros.
  * Remove unused configure options.
  * network: Don't try to get secrets for new connections.
  * Generate additional files.
  * region widget: Add keyboard layout display options.
  * l10n: Update POT file.
- Add cinnamon-control-center-3.2.0-fix-build.patch: fix building.
* Fri Jun 24 2016 sor.alexei@meowr.ru
- Update to version 3.0.1:
  * Avoid a compiler warning.
  * Fix spelling mistakes.
  * display/scrollarea.c: Fix monitor drag-and-drop alignment.
    Somewhere along the way either path_foreach_point/user_to_device
    is incorrect, or our monitor representations are being drawn
    shifted up in y, causing the mouse pointer change to occur in
    the wrong areas.
* Mon Apr 25 2016 sor.alexei@meowr.ru
- Update to version 3.0.0:
  * Remove universal-access (moved to cinnamon).
  * configure.ac: Remove PKG_CHECK_MODULES for defunct sound panel.
  * Remove sound settings in preparation for port to Cinnamon.
  * Updated pot and generated file.s
- Restore System/GUI/Other group to follow openSUSE guidelines.
* Thu Dec 24 2015 i@marguerite.su
- fix Requires: cinnamon-control-center-data, no such package:
  * it should be cinnamon-control-center-common, typo
  * no need to "more than" the Version tag in spec, they update
    and publish together, you'll unlikely run into the situation
    that sub-package's version is higher than the main package's
- remove Suggests tag:
  * no need to cycle requirements, even loose requirements.
- better RPM group:
  * System/GUI/Cinnamon, I didn't see any disadvantage for that
  * Development/Languages/C and C++, correct group
* Sun Dec 13 2015 sor.alexei@meowr.ru
- Separate common files to cinnamon-control-center-common.
* Tue Oct 27 2015 sor.alexei@meowr.ru
- Update to 2.8.1 (changes since 2.6.0):
  * Kim'ie has moved Pyonyang half an hour. Not to say several
    centuries back in time…
  * Display settings: Use a wider range of colours (there is one
    colour taken per output… connected or not… so we need to start
    with red and go all the way to blue) to identify displays, use
    more vivid colours.
  * Display settings: Do not round OSD (they appear in the corner
    so it looks a bit weird), show output names (underneath the
    display name itself).
  * Fixed wrong arguments in error_message() usage.
  * Update date-endian.c, date-endian.h.
- Remove Kim-ie-has-moved-Pyonyang-half-an-hour.patch: fixed
  upstream.
- Fix dependencies and license.
- Spec cleanup.
* Thu Oct 15 2015 ronisbr@gmail.com
- Backported a patch to add timezone 8.5
    This patch will fix the following build error:
    (process:20601): datetime-cc-panel-WARNING **: Failed to load 'backward'
    file: Failed to open file
    '/usr/share/cinnamon-control-center/datetime/backward': No such file or
    directory
    datetime-cc-panel-Message: File 'timezone_8.5.png' missing for zone
    'Asia/Pyongyang'
    The patch was obtained from Debian package.
* Tue Jun  2 2015 stefan@fam-elser.de
- update to version 2.6.0
* Thu Apr 23 2015 stefan@fam-elser.de
- update to version 2.4.2
* Mon Nov 10 2014 i@marguerite.su
- enable network panel is built
- BuildRequires: ModemManager-devel provides pkgconfig(nm-glib)
* Wed Nov  5 2014 i@marguerite.su
- update version 2.4.0
* Mon Jul 14 2014 i@marguerite.su
- update version 2.3.0
  * upstream just bump its version
- revert the /usr/lib change, openSUSE shouldn't take upstream's
  mistake as it is, should fix it a right way
* Wed Jul  9 2014 stefan@fam-elser.de
- update version 2.2.10
* Mon May 26 2014 stefan@fam-elser.de
- update version 2.2.9
* Wed May 21 2014 stefan@fam-elser.de
- update version 2.2.8
* Mon May 19 2014 stefan@fam-elser.de
- update version 2.2.7
* Thu May  1 2014 i@marguerite.su
- update version 2.2.4
* Thu Apr 17 2014 i@marguerite.su
- update version 2.2.3
* Mon Nov 25 2013 johann.luce@wanadoo.fr
- update version 2.0.9
  * [Adel Gadllah] rfkill-glib: Don't use g_assert_not_reached in type_to_string - https://mail.gnome.org/archives/commits-list/2013-May/msg04543.html
* Tue Nov 12 2013 johann.luce@wanadoo.fr
- update version 2.0.8
  * Don't use dh_translations, it removes l10n from .desktop files
  * Updated and ran generate_additional_files.py
* Fri Nov  8 2013 johann.luce@wanadoo.fr
- update version 2.0.7
  * Grey out primary button after clicking it
* Wed Oct 30 2013 i@marguerite.su
- clean the forgotten .la files
* Mon Oct 28 2013 i@marguerite.su
- update version 2.0.6
  * remove some unnecessary dependencies
  * fix dependency issue for sound panel
* Wed Oct 23 2013 i@marguerite.su
- copypac from home:cyberorg:cinnamon
- cleanup
- split library package
* Wed Oct 23 2013 stefan@fam-elser.de
- Updated to version 2.0.4
* Thu Oct 10 2013 stefan@fam-elser.de
- Updated to version 2.0.2
- Deleted the FSF address patches
* Thu Sep 19 2013 stefan@fam-elser.de
- Added two patches for fixing the FSF address
- Added two new requirements (python-lxml & python-imaging), otherweise cinnamon-control-center does not start after installation
* Tue May 21 2013 johann.luce@wanadoo.fr
- Initial Package in version 1.8
